# 🌀 blueness

The blueness of AI enables [`bluer-ai`](https://github.com/kamangir/bluer-ai).

```bash
pip install blueness
```

---

[![pylint](https://github.com/kamangir/blueness/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blueness/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blueness/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blueness/actions/workflows/pytest.yml) [![PyPI version](https://img.shields.io/pypi/v/blueness.svg)](https://pypi.org/project/blueness/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blueness)](https://pypistats.org/packages/blueness)
